# Generated by Django 3.1.2 on 2021-01-14 19:01

from django.db import migrations, models
import stylist.models


class Migration(migrations.Migration):

    dependencies = [
        ('stylist', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='style',
            name='attrs',
            field=models.JSONField(blank=True, default=stylist.models.default_attrs),
        ),
        migrations.AlterField(
            model_name='style',
            name='css_file',
            field=models.FileField(blank=True, null=True, upload_to=stylist.models.css_file_path, verbose_name='CSS File'),
        ),
    ]
